/**************************************************************

Author : Dario Di Turi
Version : 1.0
Date : 08/12/2012


********************************************************
SOFTWARE LICENSE AGREEMENT
********************************************************

The usage of the supplied software imply the acceptance of the following license.

The software supplied herewith by Dario Di Turi (the Author) 
is intended for use solely and exclusively on Microchip PIC Microcontroller
(registered mark).  
The software is owned by the Author, and is protected under applicable copyright
laws. All rights are reserved. 
Any use in violation of the foregoing restrictions may subject the user
to criminal sanctions under applicable laws (Italian or International ones),
as well as to civil liability for the breach of the terms and conditions of this license. 
Commercial use is forbidden without a written acknowledgment with the Author.
Personal or educational use is allowed if the application containing the
following software doesn't aim to commercial use or monetary earning of any kind.    

THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED TO,
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
APPLY TO THIS SOFTWARE. THE AUTHOR SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE
FOR SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.


********************************************************
PURPOSES
********************************************************

This library contains all functions needed to control the waveform generator AD9833		
Information on the AD9833 can be found on the website Analog Devices www.analog.com	

More details and pictures can be downloaded from www.LaurTec.com	
 	
*************************************************************/

#include <spi.h> 


#ifndef _AD9833_H
#define	_AD9833_H


//**************************************************
// PIN CONNECTION
// Use the default pin to SPI connection
// SDATA(SDO) to RC7 
// SCLK(SCK)  to RB1
// FSYNC(SS)  to RA5
//
// Remember:
// 1) The pull up resistor
// 2) Set the TRISx register
//**************************************************

#define FSYNC LATAbits.LATA5


//**************************************************
// COSTANTS
//**************************************************

#define RESET 0b0000000100000000
#define REG0 0
#define REG1 1
#define DOWN 0
#define UP 1
#define SIN 1
#define TRIANGLE 2
#define SQUARE 3
#define FREQUENCY0_OUT 4
#define FREQUENCY1_OUT 5
#define PHASE0_OUT 6
#define PHASE1_OUT 7
#define SLEEP_MODE 9
#define POWER_ON 10


//****************************************************************************************************
//    PRIVATE FUNCTIONS (The user should not use it)
//****************************************************************************************************

/**
 * This function write the data to the SPI bus
 *
 * @param data to write to the SPI bus  
 *
 * @return void
 *
 * @note This is a private function, the user should not use it.
 * Change this function to other microcontroller 
 */
void writeREG(unsigned int data);


/**
 * This function compose the configuration word to set AD9833 features
 *
 * @param function_type is a type of function to activate
 *
 * @return configuration word to activate the functionality required
 *
 * @note This is a private function, the user should not use it.
 */
unsigned int compose_AD9833_control_word(unsigned char function_type);


//****************************************************************************************************
//    PUBLIC FUNCTIONS
//****************************************************************************************************

/**
 * AD9833 Initialization. This function should be called before using the AD9833
 * RESET command, write 0 into register FREQ0,FREQ1,PHASE0 and PHASE1
 * Set sinusoidal waveform, FREQ0 and PHASEO out
 *
 * @param fmclk is a master frequency [0...25MHz]
 *
 * @return void
 *
 */
void init_AD9833(unsigned char fmclk);


/**
 * This function write the frequency value into FREQ0 or FREQ1 register
 *
 * @param freq_value is a frequency [0...12500000Hz]
 *
 * @param frequency_register is the register to write
 * 					0,REG0-->REGISTER0
 * 					1,REG1-->REGISTER1
 * @return void
 *
 */
void set_frequency_AD9833(unsigned long freq_value, unsigned char frequency_register);


/**
 * This function increases or decreases the LSB register frequency value of a
 * step bit for a tuning frequency
 *
 * @param tuning_step is a step bit [0...255]
 *
 * @param direction is a direction of increases or decreases
 * 					0,DOWN-->decrease 
 * 					1,UP  -->increase
 *
 * @param frequency_register is the register to write
 * 					0,REG0-->REGISTER0
 * 					1,REG1-->REGISTER1
 * @return void
 *
 */
void tuning_frequency_AD9833(unsigned char tuning_step, unsigned char direction,unsigned char frequency_register );


/**
 * This function write the phase value into PHASE0 or PHASE1 register
 *
 * @param phase_value is a phase [0...3600]
 *
 * @param phase_register is the register to write
 * 					0,REG0-->REGISTER0
 * 					1,REG1-->REGISTER1
 * @return void
 *
 */
void set_phase_AD9833(unsigned short long phase_value, unsigned char phase_register);


/**
 * This function activate features AD9833 waveform generator
 *
 * @param function_type is the function to activate
 * 			1,SIN-->sinusoidal waveform
 * 			2,TRIANGLE-->triangular waveform
 * 			3,SQUARE-->square waveform
 * 			4,FREQUENCY0_OUT-->FREQ0 register is used in the phase accumulator
 * 			5,FREQUENCY1_OUT-->FREQ1 register is used in the phase accumulator
 * 			6,PHASE0_OUT-->PHASE0 register data is added to the output of the phase accumulator
 * 			7,PHASE1_OUT-->PHASE1 register data is added to the output of the phase accumulator
 * 			9,SLEEP_MODE-->DAC powered down and internal clock disabled
 * 		   10,POWER_ON-->no power down
 * 
 * @return void
 *
 */
void set_function_AD9833(unsigned char function_type);



#endif





